@@ -4,10 +4,10 @@
  * are too numerous to list here. Please refer to the COPYRIGHT
  * file distributed with this source distribution.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -907,7 +906,7 @@ void GfxFont::loadFontAtariST(Common::String fontFilename) {
 	fontFile.skip(2); // right offset cel
 	fontFile.skip(2); // number of pixels to thicken pixels
 	fontFile.skip(2); // underline width
-	fontFile.skip(2); // lightening mask
+	fontFile.skip(2); // lightning mask
 	fontFile.skip(2); // skewing mask
 	header_Flags = fontFile.readUint16BE();
 	// bit 0 - default system font
