@@ -4,19 +4,18 @@
  * are too numerous to list here. Please refer to the COPYRIGHT
  * file distributed with this source distribution.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
-
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
-
+ *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -57,6 +56,30 @@ Screen::Screen(OSystem *system, ResMan *pResMan, ObjectMan *pObjMan) {
 	_psxCache.extPlxCache = NULL;
 	_oldScrollX = 0;
 	_oldScrollY = 0;
+
+	_textMan = 0;
+
+	for (int i = 0; i < 4; i++)
+		_layerGrid[i] = 0;
+
+	for (int i = 0; i < 4; i++)
+		_layerBlocks[i] = 0;
+
+	_parallax[0] = 0;
+	_parallax[1] = 0;
+
+	_fullRefresh = 0;
+
+	for (int i = 0; i < MAX_SORT; i++) {
+		_sortList[i].id = 0;
+		_sortList[i].y = 0;
+	}
+	_scrnSizeX = 0;
+	_scrnSizeY = 0;
+	_gridSizeX = 0;
+	_gridSizeY = 0;
+	_fadingDirection = 0;
+	_isBlack = 0;
 }
 
 Screen::~Screen() {
@@ -106,7 +129,7 @@ void Screen::setScrolling(int16 offsetX, int16 offsetY) {
 	} else {
 		// SCROLL_FLAG == 0, this usually means that the screen is smaller than 640x400 and doesn't need scrolling at all
 		// however, it can also mean that the gamescript overwrote the scrolling flag to take care of scrolling directly,
-		// (see bug report #1345130) so we ignore the offset arguments in this case
+		// (see bug report #2327) so we ignore the offset arguments in this case
 		Logic::_scriptVars[SCROLL_OFFSET_X] = CLIP<int32>(Logic::_scriptVars[SCROLL_OFFSET_X], 0, Logic::_scriptVars[MAX_SCROLL_OFFSET_X]);
 		Logic::_scriptVars[SCROLL_OFFSET_Y] = CLIP<int32>(Logic::_scriptVars[SCROLL_OFFSET_Y], 0, Logic::_scriptVars[MAX_SCROLL_OFFSET_Y]);
 		if ((Logic::_scriptVars[SCROLL_OFFSET_X] != _oldScrollX) || (Logic::_scriptVars[SCROLL_OFFSET_Y] != _oldScrollY)) {
@@ -134,7 +157,7 @@ void Screen::fnSetPalette(uint8 start, uint16 length, uint32 id, bool fadeUp) {
 	if (start == 0) // force color 0 to black
 		palData[0] = palData[1] = palData[2] = 0;
 
-	if (SwordEngine::isMac()) {  // see bug #1701058
+	if (SwordEngine::isMac()) {  // see bug #8636
 		if (start != 0 && start + length == 256) // and force color 255 to black as well
 			palData[(length - 1) * 3 + 0] = palData[(length - 1) * 3 + 1] = palData[(length - 1) * 3 + 2] = 0;
 	}
@@ -384,7 +407,7 @@ void Screen::draw() {
 			for (uint16 cnty = scrnScrlY; (cnty < _scrnSizeY) && (cnty < scrnHeight + scrnScrlY); cnty++)
 				for (uint16 cntx = 0; cntx < _scrnSizeX; cntx++) {
 					if (*src)
-						if (!(SwordEngine::isMac()) || *src != 255) // see bug #1701058
+						if (!(SwordEngine::isMac()) || *src != 255) // see bug #8636
 							*dest = *src;
 					src++;
 					dest++;
@@ -580,7 +603,7 @@ void Screen::verticalMask(uint16 x, uint16 y, uint16 bWidth, uint16 bHeight) {
 
 	for (uint16 blkx = 0; blkx < bWidth; blkx++) {
 		// A sprite can be masked by several layers at the same time,
-		// so we have to check them all. See bug #917427.
+		// so we have to check them all. See bug #1536.
 		for (int16 level = _roomDefTable[_currentScreen].totalLayers - 2; level >= 0; level--) {
 			if (_layerGrid[level][gridX + blkx + gridY * lGridSizeX]) {
 				uint16 *grid = _layerGrid[level] + gridX + blkx + gridY * lGridSizeX;
